/**
 * @author Parfeniuk Bogdan
 *
 * @section LICENSE
 *
 *2016 ARM
 *
 */

#ifndef LCD_H
#define LCD_H

/**
 * Includes
 */

#include "stm32f10x_conf.h"
#include "font.h"

/**
 * Defines
 */

#define LCD_DB 8
#define LCD_IOP GPIOE
#define LCD_CTP GPIOC
#define LCD_PINS (GPIO_Pin_0 | GPIO_Pin_1 | GPIO_Pin_2 | GPIO_Pin_3 | GPIO_Pin_4 | GPIO_Pin_5 | GPIO_Pin_6 | GPIO_Pin_7)
#define LCD_CONT (GPIO_Pin_1 |GPIO_Pin_2 | GPIO_Pin_3 | GPIO_Pin_5)

#define RS GPIO_Pin_1
#define WR GPIO_Pin_2
#define CS GPIO_Pin_3
#define REST GPIO_Pin_5


#define CS_LOW GPIO_ResetBits(LCD_CTP, CS);
#define RS_LOW GPIO_ResetBits(LCD_CTP, RS);
#define WR_LOW GPIO_ResetBits(LCD_CTP, WR);
#define REST_LOW GPIO_ResetBits(LCD_CTP, REST);

#define CS_HIGH GPIO_SetBits(LCD_CTP, CS);
#define RS_HIGH GPIO_SetBits(LCD_CTP, RS);
#define WR_HIGH GPIO_SetBits(LCD_CTP, WR);
#define REST_HIGH GPIO_SetBits(LCD_CTP, REST);


unsigned int IC_CODE; //Stores Driver IC ID (either SPFD5408A  or ST7781R)

//Basic Colors
#define RED		0xf800
#define GREEN		0x7e00
#define BLUE		0x001f
#define BLACK		0x0000
#define YELLOW		0xffe0
#define WHITE		0xffff

//Other Colors
#define CYAN		0x07ff
#define BRIGHT_RED	0xf810
#define GRAY1		0x8410
#define GRAY2		0x4208
#define Magenta     0xF81F
//#define DISP_ORIENTATION                  0
#define DISP_ORIENTATION               90
//#define DISP_ORIENTATION             180
//#define DISP_ORIENTATION          270

#if (DISP_ORIENTATION == 90) || (DISP_ORIENTATION == 270)

#define  MAX_X        320
#define  MAX_Y        240

#elif (DISP_ORIENTATION == 0) || (DISP_ORIENTATION == 180)

#define  MAX_X        240
#define  MAX_Y        320

#endif

#define WINDOW_XADDR_START	0x0050 // Horizontal Start Address Set
#define WINDOW_XADDR_END	0x0051 // Horizontal End Address Set
#define WINDOW_YADDR_START	0x0052 // Vertical Start Address Set
#define WINDOW_YADDR_END	0x0053 // Vertical End Address Set
#define GRAM_XADDR		    0x0020 // GRAM Horizontal Address Set
#define GRAM_YADDR		    0x0021 // GRAM Vertical Address Set
#define GRAMWR 			    0x0022 // memory write


void init (void);

void sendCommand(unsigned int index);
void sendData(unsigned int data);
void pushData(unsigned int data);
unsigned char getData(void);
unsigned int readRegister(unsigned int index);
void LCD_clear(void);


void TFT_set_cursor(unsigned int poX, unsigned int poY);
void TFT_set_display_window(unsigned int x_pos, unsigned int y_pos, unsigned int w, unsigned int h);
void Draw_BMP(unsigned int x_pos, unsigned int y_pos, unsigned int H, unsigned int W, unsigned char *bitmap);

void setPixel(unsigned int poX, unsigned int poY,unsigned int color);
void drawLine(unsigned int x0,unsigned int y0,unsigned int x1,unsigned int y1,unsigned int color);
void drawVerticalLine(unsigned int poX, unsigned int poY,unsigned int length,unsigned int color);
void drawHorizontalLine(unsigned int poX, unsigned int poY,unsigned int length,unsigned int color);
void drawRectangle(unsigned int poX, unsigned int poY, unsigned int length,unsigned int width,unsigned int color);
void fillRectangle(unsigned int poX, unsigned int poY, unsigned int length, unsigned int width, unsigned int color);
void drawCircle(int poX, int poY, int r,unsigned int color);
void fillCircle(int poX, int poY, int r,unsigned int color);
void drawChar(unsigned char ascii,unsigned int poX, unsigned int poY,unsigned int size, unsigned int fgcolor);
void drawString(char *string,unsigned int poX, unsigned int poY,unsigned int size,unsigned int fgcolor);
unsigned char drawNumber(long long_num,unsigned int poX, unsigned int poY,unsigned int size,unsigned int fgcolor);

unsigned char drawFloat(float floatNumber,unsigned char decimal,unsigned int poX, unsigned int poY,unsigned int size,unsigned int fgcolor);
void delay(unsigned long ms);
void all_pin_input(void);
void all_pin_output(void);
void all_pin_low(void);

void setOrientation(unsigned int HV);
void LCD_WriteReg(unsigned int INDEX, unsigned int DATA);

GPIO_InitTypeDef		LCDCTR_Setup;
GPIO_InitTypeDef		LCDIO_Setup;



 /**
     *
     *
     * @param
     * @param
     */

void CONFIG_LCD_PINS(void);


#endif /* LCD_H */

